@@ -4,10 +4,10 @@ ABBREVIATIONS = ["dr", "jr", "mr", "mrs", "ms", "msgr", "prof", "sr", "st"]
 
 SUB_PAIRS = [("M.", "Monsieur")]
 
-ALL_PUNC = u"?!？！.,¡()[]¿…‥،;:—。，、：\n"
+ALL_PUNC = "?!？！.,¡()[]¿…‥،;:—。，、：\n"
 
-TONE_MARKS = u"?!？！"
+TONE_MARKS = "?!？！"
 
-PERIOD_COMMA = u".,"
+PERIOD_COMMA = ".,"
 
-COLON = u":"
+COLON = ":"
